librpm-sys-0.0.2 has been yanked.
Visit the last successful build:
librpm-sys-0.2.1
librpm-sys: bindgen wrapper for librpm (RedHat Package Manager library)
This crate uses bindgen to generate an unsafe FFI wrapper for the librpm C library, which provides an API for interacting with the RedHat Package Manager (RPM) and .rpm files.
This crate isn't intended to be used directly, but instead provides an unsafe, low-level binding used by the higher level librpm crate, which aims to provide a higher-level wrapper which can be used from safe Rust code.
License
The librpm-sys crate is distributed under the terms of the Apache License (Version 2.0).
See LICENSE file in the iqlusion-io/crates toplevel directory for more
information.